@@ -596,7 +596,7 @@ def load_img_dir(path, resize_factor=0.5):
     path_glob = Path(path).glob("**/*")
     files = [x for x in path_glob if x.is_file()]
     if len(files) == 0:
-        raise UserWarning("No files detected at the input path.")
+        raise UserWarning("No files found at the input path.")
 
     imgs = []
     for file in files:
@@ -752,12 +752,12 @@ def maskrcnn_process_video(
     class_map,
     config,
     output_shape=(700, 700),
-    show_first_frame=True,
+    show_first_frame=False,
     frame_max=1e4,
     fps=30,
 ):
     """
-    Processes a .MOV, adding segmentation, labels, and/or bboxes and 
+    Processes a .MOV, adding segmentation, labels, and/or bboxes and
     writes out a processed version of the original .MOV
 
     Args:
@@ -765,8 +765,8 @@ def maskrcnn_process_video(
         raw_video_path (str): path to raw .MOV file. Should work with any
             file type compatible with cv2.VideoCapture.
 
-        processed_video_path (str): path where processed video will be 
-            written. 
+        processed_video_path (str): path where processed video will be
+            written.
 
         device (str): what device to put model and imgs. Use following
             call: device = "cuda" if torch.cuda.is_available() else "cpu"
@@ -798,19 +798,19 @@ def maskrcnn_process_video(
                       "label_size": 1,
                       "label_width": 1}
 
-        output_shape (tuple[int,int]): size of the ouput video. 
-        show_first_frame (bool): used to sanity check. Set to true to see the 
-            result of first frame. 
-        frame_max (int): used to limit the time this takes and to sanity 
-            check things. Set to 10 to be sure things are working. 
-        fps (int): frames per second of video. Default for google photos 
-            is 30. 
+        output_shape (tuple[int,int]): size of the ouput video.
+        show_first_frame (bool): used to sanity check. Set to true to see the
+            result of first frame.
+        frame_max (int): used to limit the time this takes and to sanity
+            check things. Set to 10 to be sure things are working.
+        fps (int): frames per second of video. Default for google photos
+            is 30.
 
     Returns:
         None
     """
-
-    print("Video exists at given raw_video_path: ", Path(raw_video_path).is_file())
+    if not Path(raw_video_path).is_file():
+        raise UserWarning("No file found at raw_video_path.")
 
     # Capture for reading raw video.
     cap = cv2.VideoCapture(str(raw_video_path))
